@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- $Id: battstat_applet.c,v 1.111 2005/07/14 06:53:16 ryanl Exp $
+ $Id: battstat_applet.c,v 1.118 2005/12/06 04:21:27 ryanl Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -25,6 +25,8 @@
 
 #include <stdio.h>
 
+#include <sys/types.h>
+#include <sys/wait.h>
 #include <err.h>
 #include <stdlib.h>
 #include <string.h>
@@ -276,7 +278,7 @@ allocate_battery_colours( void )
 static int instances;
 
 static const char *
-static_global_initialisation(void)
+static_global_initialisation( int no_hal )
 {
   const char *err;
 
@@ -286,7 +288,7 @@ static_global_initialisation(void)
   allocate_battery_colours();
   initialise_global_pixmaps();
   glade_init();
-  err = power_management_initialise();
+  err = power_management_initialise( no_hal );
 
   return err;
 }
@@ -381,18 +383,32 @@ get_remaining (BatteryStatus *info)
 }
 
 static gboolean
-battery_full_notify (void)
+battery_full_notify (GtkWidget *applet)
 {
 #ifdef HAVE_LIBNOTIFY
 	static NotifyIcon *icon = NULL;
+	NotifyHints *hints;
+	GtkRequisition size;
+	int x, y;
 	
 	if (!notify_is_initted () && !notify_init (_("Battery Monitor")))
 		return FALSE;
 
-	/* XXX: this icon is not found in the theme... strange */
+	/* FIXME - this is an issue in something... */
 	/* if (!icon)
 		icon = notify_icon_new_from_uri ("gnome-dev-battery"); */
+
+	/* get the position of the applet on the panel */
+	gdk_window_get_origin (applet->window, &x, &y);
+	gtk_widget_size_request (applet, &size);
+	x += size.width / 2;
+	y += size.height;
+
+	hints = notify_hints_new ();
+	notify_hints_set_int (hints, "x", x);
+	notify_hints_set_int (hints, "y", y);
 	
+	/* send the notification */
 	if (!notify_send_notification (NULL,
 				"device",
 				NOTIFY_URGENCY_NORMAL,
@@ -400,7 +416,7 @@ battery_full_notify (void)
 				NULL,		/* body text */
 				icon,		/* icon */
 				TRUE, 0,	/* expiry, server default */
-				NULL,		/* hints */
+				hints,		/* hints */
 				NULL,		/* no user_data */
 				0))		/* no actions */
 		return FALSE;
@@ -414,10 +430,10 @@ battery_full_notify (void)
 /* Show a dialog notifying the user that their battery is done charging.
  */
 static void
-battery_full_dialog( void )
+battery_full_dialog (GtkWidget *applet)
 {
   /* first attempt to use libnotify */
-  if (battery_full_notify ())
+  if (battery_full_notify (applet))
 	  return;
   
   GtkWidget *dialog, *hbox, *image, *label;
@@ -473,11 +489,37 @@ battery_low_dialog_destroy( ProgressData *battstat )
   battstat->battery_low_label = NULL;
 }
 
+/* Determine if suspend is unsupported.  For the time being this involves
+ * distribution-specific magic :(
+ */
+/* #define HAVE_PMI */
+static gboolean
+is_suspend_unavailable( void )
+{
+#ifdef HAVE_PMI
+  int status;
+
+  status = system( "pmi query suspend" );
+
+  /* -1 - fail (pmi unavailable?).     return 'false' since we don't know.
+   * 0  - success (can suspend).       return 'false' since not unavailable.
+   * 1  - success (cannot suspend).    return 'true' since unavailable.
+   */
+  if( WEXITSTATUS( status ) == 1 )
+    return TRUE;
+  else
+    return FALSE;
+#else
+  return FALSE; /* return 'false' since we don't know. */
+#endif
+}
+
 /* Update the text label in the battery low dialog.
  */
 static void
 battery_low_update_text( ProgressData *battstat, BatteryStatus *info )
 {
+  const char *suggest;
   gchar *remaining, *new_label;
   GtkRequisition size;
 
@@ -505,18 +547,27 @@ battery_low_update_text( ProgressData *battstat, BatteryStatus *info )
                                  info->minutes ),
                                info->minutes,info->percent );
 
-  new_label = g_strdup_printf (
+  if( is_suspend_unavailable() )
+    /* TRANSLATORS: this is a list, it is left as a single string
+     * to allow you to make it appear like a list would in your
+     * locale.  This is if the laptop does not support suspend. */
+    suggest = _("To avoid losing your work:\n"
+                " \xE2\x80\xA2 plug your laptop into external power, or\n"
+                " \xE2\x80\xA2 save open documents and shut your laptop down."
+               );
+  else
+    /* TRANSLATORS: this is a list, it is left as a single string
+     * to allow you to make it appear like a list would in your
+     * locale.  This is if the laptop supports suspend. */
+    suggest = _("To avoid losing your work:\n"
+                " \xE2\x80\xA2 suspend your laptop to save power,\n"
+                " \xE2\x80\xA2 plug your laptop into external power, or\n"
+                " \xE2\x80\xA2 save open documents and shut your laptop down."
+               );
+
+  new_label = g_strdup_printf(
 		"<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s\n\n%s",
-		_("Your battery is running low"),
-		remaining,
-		/* TRANSLATORS: this is a list, it is left as a single string
-		 * to allow you to make it appear like a list would in your
-		 * locale. */
-		_("To avoid losing your work:\n"
-		  " \xE2\x80\xA2 suspend your laptop to save power,\n"
-		  " \xE2\x80\xA2 plug your laptop into external power, or\n"
-		  " \xE2\x80\xA2 save open documents and shut your laptop down."
-		  ));
+		_("Your battery is running low"), remaining, suggest );
 
   gtk_label_set_markup( battstat->battery_low_label, new_label );
   g_free( remaining );
@@ -543,6 +594,8 @@ battery_low_dialog( ProgressData *battery, BatteryStatus *info )
 		 GTK_STOCK_OK,
 		 GTK_RESPONSE_ACCEPT,
 		 NULL);
+  gtk_dialog_set_default_response( GTK_DIALOG (battery->battery_low_dialog),
+                                   GTK_RESPONSE_ACCEPT );
 
   g_signal_connect_swapped( GTK_OBJECT (battery->battery_low_dialog),
                             "response",
@@ -966,7 +1019,7 @@ check_for_updates( gpointer data )
 
     if(battstat->fullbattnot)
     {
-      battery_full_dialog();
+      battery_full_dialog (battstat->applet);
  
       if (battstat->beep)
         gdk_beep();
@@ -1002,6 +1055,8 @@ check_for_updates( gpointer data )
        battstat->last_batt_life != info.percent) ||
       (battstat->showtext == APPLET_SHOW_TIME &&
        battstat->last_minutes != info.minutes) ||
+       battstat->last_acline_status != info.on_ac_power ||
+       battstat->last_present != info.present ||
        battstat->refresh_label ) /* set by properties dialog */
   {
     /* Update the label */
@@ -1015,6 +1070,7 @@ check_for_updates( gpointer data )
   battstat->last_batt_life = info.percent;
   battstat->last_minutes = info.minutes;
   battstat->last_acline_status = info.on_ac_power;
+  battstat->last_present = info.present;
 
   return TRUE;
 }
@@ -1103,9 +1159,13 @@ about_cb( BonoboUIComponent *uic, ProgressData *battstat, const char *verb )
   const gchar *documenters[] = {
     "J\xC3\xB6rgen Pehrson <jp@spektr.eu.org>",
     "Trevor Curtis <tcurtis@somaradio.ca>",
+    "Davyd Madeley <davyd@madeley.id.au>",
     NULL
   };
 
+  if( power_management_using_hal() )
+    authors[4] = "Ryan Lortie <desrt@desrt.ca> \xe2\x98\x86";
+
   gtk_show_about_dialog( NULL,
     "name",                _("Battery Charge Monitor"), 
     "version",             VERSION,
@@ -1121,6 +1181,22 @@ about_cb( BonoboUIComponent *uic, ProgressData *battstat, const char *verb )
     NULL );
 }
 
+/* Rotate text on side panels.  Called on initial startup and when the
+ * orientation changes (ie: the panel we were on moved or we moved to
+ * another panel).
+ */
+static void
+setup_text_orientation( ProgressData *battstat )
+{
+  if( battstat->orienttype == PANEL_APPLET_ORIENT_RIGHT )
+    gtk_label_set_angle( GTK_LABEL( battstat->percent ), 90 );
+  else if( battstat->orienttype == PANEL_APPLET_ORIENT_LEFT )
+    gtk_label_set_angle( GTK_LABEL( battstat->percent ), 270 );
+  else
+    gtk_label_set_angle( GTK_LABEL( battstat->percent ), 0 );
+}
+
+
 /* This signal is delivered by the panel when the orientation of the applet
    has changed.  This is either because the applet has just been created,
    has just been moved to a new panel or the panel that the applet was on
@@ -1141,6 +1217,7 @@ change_orient (PanelApplet       *applet,
     /* The applet changing orientation very likely involves the layout
        being changed to better fit the new shape of the panel.
     */
+    setup_text_orientation( battstat );
     reconfigure_layout( battstat );
   }
 }
@@ -1513,10 +1590,13 @@ battstat_applet_fill (PanelApplet *applet)
   ProgressData *battstat;
   AtkObject *atk_widget;
   const char *err;
+  int no_hal;
 
   if (DEBUG) g_print("main()\n");
 
-  if( (err = static_global_initialisation()) )
+  no_hal = panel_applet_gconf_get_bool( applet, "no_hal", NULL );
+
+  if( (err = static_global_initialisation( no_hal )) )
     battstat_error_dialog( GTK_WIDGET (applet), err );
 
   gtk_window_set_default_icon_name ("gnome-dev-battery");
@@ -1547,6 +1627,7 @@ battstat_applet_fill (PanelApplet *applet)
 
   load_preferences (battstat);
   create_layout (battstat);
+  setup_text_orientation( battstat );
 
   battstat->pixtimer = gtk_timeout_add (1000, check_for_updates, battstat);
 
