@@ -18,17 +18,15 @@
 #include <dirent.h>
 #include <string.h>
 #include <time.h>
-#include <gnome.h>
-#include <panel-applet.h>
-#include <gconf/gconf-client.h>
-#include <panel-applet-gconf.h>
 
+#include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
-#include <libgnomeui/libgnomeui.h>
-#include <libgnome/libgnome.h>
-#include <libgnomeui/gnome-window-icon.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <libart_lgpl/libart.h>
+#include <gconf/gconf-client.h>
+#include <libgnome/gnome-desktop-item.h> 
+#include <libgnomeui/gnome-help.h>
+#include <panel-applet.h>
+#include <panel-applet-gconf.h>
 
 #include "global.h"
 
@@ -37,7 +35,7 @@ about_cb (BonoboUIComponent *uic,
 	  MultiloadApplet   *ma,
 	  const char        *name)
 {
-    static const gchar *authors[] =
+    const gchar * const authors[] =
     {
 		"Martin Baulig <martin@home-of-linux.org>",
 		"Todd Kulesza <fflewddur@dropline.net>",
@@ -46,7 +44,7 @@ about_cb (BonoboUIComponent *uic,
 		NULL
     };
 
-    const gchar *documenters[] =
+    const gchar * const documenters[] =
     {
 		"Chee Bin HOH <cbhoh@gnome.org>",
 		"Sun GNOME Documentation Team <gdocteam@sun.com>",
@@ -96,12 +94,23 @@ static void
 start_procman (MultiloadApplet *ma)
 {
 	GError *error = NULL;
+	GnomeDesktopItem *ditem;
 
 	g_return_if_fail (ma != NULL);
 
-	gdk_spawn_command_line_on_screen (
-			gtk_widget_get_screen (GTK_WIDGET (ma->applet)),
-			"gnome-system-monitor", &error);
+	if ((ditem = gnome_desktop_item_new_from_basename ("gnome-system-monitor.desktop", 0, NULL))) {
+		gnome_desktop_item_set_launch_time (ditem, gtk_get_current_event_time ());
+		gnome_desktop_item_launch_on_screen (ditem, NULL,
+		                                     GNOME_DESKTOP_ITEM_LAUNCH_ONLY_ONE,
+		                                     gtk_widget_get_screen (GTK_WIDGET (ma->applet)),
+		                                     -1, &error);
+		gnome_desktop_item_unref (ditem);
+	}
+	else {	
+	     	gdk_spawn_command_line_on_screen (
+				gtk_widget_get_screen (GTK_WIDGET (ma->applet)),
+				"gnome-system-monitor", &error);
+	}
 
 	if (error) {
 		GtkWidget *dialog;
@@ -307,7 +316,7 @@ multiload_key_press_event_cb (GtkWidget *widget, GdkEventKey *event, MultiloadAp
 void
 multiload_applet_tooltip_update(LoadGraph *g)
 {
-	gint i, total_used, percent, mem_used, used_percent;
+	guint i, total_used, percent, mem_used, used_percent;
 	gchar *tooltip_text, *name;
 
 	g_return_if_fail(g);
@@ -329,7 +338,7 @@ multiload_applet_tooltip_update(LoadGraph *g)
 	else if (!strncmp (g->name, "diskload", strlen("diskload")))
 		name = g_strdup(_("Disk"));
 	else
-		name = g_strdup(_("Resource"));
+		g_assert_not_reached();
 	
 	/* fill data[0] with the current load */
 	g->get_data (g->draw_height, g->data[0], g);
@@ -345,11 +354,29 @@ multiload_applet_tooltip_update(LoadGraph *g)
 		used_percent = 100 * (gdouble)mem_used / (gdouble)g->draw_height;
 		used_percent = CLAMP (used_percent, 0, 100);
 		
-		tooltip_text = g_strdup_printf(_("%s:\n%d%% in use of which\n%d%% is cache"), name, percent,
-				percent - used_percent);
-	} else
-		tooltip_text = g_strdup_printf(_("%s:\n%d%% in use"), name, percent);
-	
+		/* xgettext: use and cache are > 1 most of the time,
+		   please assume that they always are.
+		 */
+		tooltip_text = g_strdup_printf(_("%s:\n"
+						 "%u%% in use of which\n"
+						 "%u%% is cache"),
+					       name,
+					       percent,
+					       percent - used_percent);
+	} else {
+		const char *msg;
+
+		msg = ngettext("%s:\n"
+			       "%u%% in use",
+			       "%s:\n"
+			       "%u%% in use",
+			       percent);
+
+		tooltip_text = g_strdup_printf(msg,
+					       name,
+					       percent);
+	}
+
 	gtk_tooltips_set_tip(g->tooltips, g->disp, tooltip_text, tooltip_text);
 		
 	g_free(tooltip_text);
@@ -358,6 +385,51 @@ multiload_applet_tooltip_update(LoadGraph *g)
 	return;
 }
 
+static void
+multiload_create_graphs(MultiloadApplet *ma)
+{
+	struct { const char *label;
+		 const char *name;
+		 int num_colours;
+		 LoadGraphDataFunc callback;
+	       } graph_types[] = {
+			{ _("CPU Load"),     "cpuload",  5, GetLoad },
+			{ _("Memory Load"),  "memload",  5, GetMemory },
+			{ _("Net Load"),     "netload",  5, GetNet },
+			{ _("Swap Load"),    "swapload", 2, GetSwap },
+			{ _("Load Average"), "loadavg",  2, GetLoadAvg },
+			{ _("Disk Load"),    "diskload", 3, GetDiskLoad }
+		};
+
+	gint speed, size;
+	gint i;
+
+	speed = panel_applet_gconf_get_int (ma->applet, "speed", NULL);
+	size = panel_applet_gconf_get_int (ma->applet, "size", NULL);
+	speed = MAX (speed, 50);
+	size = CLAMP (size, 10, 400);
+
+	for (i = 0; i < G_N_ELEMENTS (graph_types); i++)
+	{
+		gboolean visible;
+		char *key;
+
+		key = g_strdup_printf ("view_%s", graph_types[i].name);
+		visible = panel_applet_gconf_get_bool (ma->applet, key, NULL);
+		g_free (key);
+
+		ma->graphs[i] = load_graph_new (ma,
+				                graph_types[i].num_colours,
+						graph_types[i].label,
+                                                i,
+						speed,
+						size,
+						visible,
+						graph_types[i].name,
+						graph_types[i].callback);
+	}
+}
+
 /* remove the old graphs and rebuild them */
 void
 multiload_applet_refresh(MultiloadApplet *ma)
@@ -396,14 +468,8 @@ multiload_applet_refresh(MultiloadApplet *ma)
 	gtk_container_add(GTK_CONTAINER(ma->applet), ma->box);
 			
 	/* create the NGRAPHS graphs, passing in their user-configurable properties with gconf. */
-	
-	ma->graphs[0] = cpuload_applet_new(ma->applet, NULL);
-	ma->graphs[1] = memload_applet_new(ma->applet, NULL);
-	ma->graphs[2] = netload_applet_new(ma->applet, NULL);
-	ma->graphs[3] = swapload_applet_new(ma->applet, NULL);
-	ma->graphs[4] = loadavg_applet_new(ma->applet, NULL);
-	ma->graphs[5] = diskload_applet_new(ma->applet, NULL);
-	
+	multiload_create_graphs (ma);
+
 	/* only start and display the graphs the user has turned on */
 
 	for (i = 0; i < NGRAPHS; i++) {
@@ -443,6 +509,7 @@ multiload_applet_new(PanelApplet *applet, const gchar *iid, gpointer data)
 	
 	ma->about_dialog = NULL;
 	ma->prop_dialog = NULL;
+        ma->last_clicked = 0;
 
 	gtk_window_set_default_icon_name ("gnome-monitor");
 	
@@ -515,4 +582,4 @@ PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_MultiLoadApplet_Factory",
 				   "multiload",
 				   "0",
 				   multiload_factory,
-				   NULL);
+				   NULL)
